@@ -11,7 +11,7 @@ from ..parameter import Parameter
 from ...tensor import Tensor
 import torchplus
 from .. import functional as F
-from .. import init
+import torch.nn.init as init
 
 class Linear(Module):
 
