@@ -826,7 +826,7 @@ class Tensor(torch.Tensor):
             raise TypeError("unsqueeze function only accept either argument or positional argument. But both are given")
         if dim is None:
             dim = dims
-        if isinstance(dim, int):
+        if isinstance(dim, builtin.int):
             dim = (dim, )
         if len(dim) == 0: dim = (0,)
         for d in dim:
@@ -839,7 +839,7 @@ class Tensor(torch.Tensor):
             raise TypeError("unsqueeze function only accept either argument or positional argument. But both are given")
         if dim is None:
             dim = dims
-        if isinstance(dim, int):
+        if isinstance(dim, builtins.int):
             dim = (dim, )
         if len(dim) == 0: dim = (0,)
         for d in dim: super(torch.Tensor, self).unsqueeze_(d)
